onEndDateChanged property
Called when the user changes the end date of the selected range.
Implementation
final ValueChanged<DateTime?>? onEndDateChanged;
Called when the user changes the end date of the selected range.
final ValueChanged<DateTime?>? onEndDateChanged;